@@ -1,10 +1,13 @@
 from functools import wraps
+from typing import Any, Callable, TypeVar
 
 from allure_commons._core import plugin_manager
 from allure_commons.types import LabelType, LinkType
 from allure_commons.utils import uuid4
 from allure_commons.utils import func_parameters, represent
 
+_TFunc = TypeVar("_TFunc", bound=Callable[..., Any])
+
 
 def safely(result):
     if result:
@@ -67,6 +70,10 @@ def id(id):
     return label(LabelType.ID, id)
 
 
+def manual(fn):
+    return label(LabelType.MANUAL, True)(fn)
+
+
 def link(url, link_type=LinkType.LINK, name=None):
     return safely(plugin_manager.hook.decorate_as_link(url=url, link_type=link_type, name=name))
 
@@ -137,6 +144,10 @@ class Dynamic(object):
     def sub_suite(sub_suite_name):
         Dynamic.label(LabelType.SUB_SUITE, sub_suite_name)
 
+    @staticmethod
+    def manual():
+        return Dynamic.label(LabelType.MANUAL, True)
+
 
 def step(title):
     if callable(title):
@@ -159,7 +170,7 @@ class StepContext:
         plugin_manager.hook.stop_step(uuid=self.uuid, title=self.title, exc_type=exc_type, exc_val=exc_val,
                                       exc_tb=exc_tb)
 
-    def __call__(self, func):
+    def __call__(self, func: _TFunc) -> _TFunc:
         @wraps(func)
         def impl(*a, **kw):
             __tracebackhide__ = True
@@ -167,6 +178,7 @@ class StepContext:
             args = list(map(lambda x: represent(x), a))
             with StepContext(self.title.format(*args, **params), params):
                 return func(*a, **kw)
+
         return impl
 
 
